@@ -11,8 +11,8 @@ class LoopbackVolume(Volume):
 
 	def _before_create(self, e):
 		self.image_path = e.image_path
-		vol_size = str(self.size.get_qty_in('MiB')) + 'M'
-		log_check_call(['qemu-img', 'create', '-f', 'raw', self.image_path, vol_size])
+		size_opt = '--size={mib}M'.format(mib=self.size.bytes.get_qty_in('MiB'))
+		log_check_call(['truncate', size_opt, self.image_path])
 
 	def _before_attach(self, e):
 		[self.loop_device_path] = log_check_call(['losetup', '--show', '--find', self.image_path])
