@@ -2,7 +2,7 @@
 
 def validate_manifest(data, validator, error):
 	import os.path
-	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.json'))
+	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.yml'))
 	validator(data, schema_path)
 
 
@@ -10,4 +10,5 @@ def resolve_tasks(taskset, manifest):
 	from bootstrapvz.common.tasks import ssh
 	from tasks import SetRootPassword
 	taskset.discard(ssh.DisableSSHPasswordAuthentication)
+	taskset.add(ssh.EnableRootLogin)
 	taskset.add(SetRootPassword)
