@@ -5,13 +5,9 @@ from bootstrapvz.common.tasks import initd
 from bootstrapvz.common.tasks import ssh
 
 
-def initialize():
-	pass
-
-
 def validate_manifest(data, validator, error):
 	import os.path
-	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.json'))
+	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.yml'))
 	validator(data, schema_path)
 
 
@@ -19,6 +15,7 @@ def resolve_tasks(taskset, manifest):
 	taskset.update(task_groups.get_standard_groups(manifest))
 
 	taskset.update([tasks.packages.DefaultPackages,
+	                loopback.AddRequiredCommands,
 	                loopback.Create,
 	                initd.InstallInitScripts,
 	                ssh.AddOpenSSHPackage,
@@ -27,7 +24,7 @@ def resolve_tasks(taskset, manifest):
 	                loopback.MoveImage,
 	                ])
 
-	if manifest.bootstrapper.get('virtio', []):
+	if manifest.provider.get('virtio', []):
 		from tasks import virtio
 		taskset.update([virtio.VirtIO])
 
