@@ -3,13 +3,9 @@ import tasks.packages
 from bootstrapvz.common.tasks import loopback
 
 
-def initialize():
-	pass
-
-
 def validate_manifest(data, validator, error):
 	import os.path
-	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.json'))
+	schema_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'manifest-schema.yml'))
 	validator(data, schema_path)
 
 
@@ -17,11 +13,12 @@ def resolve_tasks(taskset, manifest):
 	taskset.update(task_groups.get_standard_groups(manifest))
 
 	taskset.update([tasks.packages.DefaultPackages,
+	                loopback.AddRequiredCommands,
 	                loopback.Create,
 	                loopback.MoveImage,
 	                ])
 
-	if manifest.bootstrapper.get('guest_additions', False):
+	if manifest.provider.get('guest_additions', False):
 		from tasks import guest_additions
 		taskset.update([guest_additions.CheckGuestAdditionsPath,
 		                guest_additions.AddGuestAdditionsPackages,
